import { EditorView } from '@codemirror/view';
import { HighlightStyle, syntaxHighlighting } from '@codemirror/language';
import { tags } from '@lezer/highlight';
import { generalScroller, generalPlaceholder, generalMatching, generalTooltip, generalGutter, generalLine, generalPanel, generalSearchField, generalCursor, generalContent } from '@utils';

/**
 * Enhanced Solarized Light theme color definitions
 * ---------------------------------------------
 * Colors organized by function with visual color blocks
 */
// Base colors from Solarized palette
const base00 = '#657b83'; // Body text/default text color
const base01 = '#586e75'; // Optional emphasized content
const base02 = '#073642'; // Background highlights
const base03 = '#002b36'; // Comments, invisible, line highlighting
const base04 = '#dfd9c8'; // Dark background tint
const base05 = '#93a1a1'; // Default foreground/UI text color
const base06 = '#cceeff7a'; // Light background tint (for selection)
const base07 = '#fdf6e3'; // Background - light base
const base08 = '#eee8d5'; // Background tint - light secondary
// Accent colors from Solarized palette
const base_red = '#dc322f'; // Red
const base_orange = '#cb4b16'; // Orange
const base_yellow = '#b58900'; // Yellow
const base_green = '#859900'; // Green
const base_cyan = '#2aa198'; // Cyan
const base_blue = '#268bd2'; // Blue
const base_violet = '#6c71c4'; // Violet
const base_magenta = '#d33682'; // Magenta
// UI specific colors
const invalid = '#d30102'; // Bright red for errors
const darkBackground = base04; // Darker background for panels
const highlightBackground = base06; // Active line highlight
const background = base07; // Main editor background
const tooltipBackground = '#f0e9d7'; // Tooltip background
const selection = '#ffd07a'; // Selection background
const selectionMatch = '#e1dbca90'; // Selection match with opacity
const cursor = base01; // Cursor color
const activeBracketBg = '#93a1a140'; // Active bracket background with opacity
const activeBracketBorder = base_blue; // Active bracket border - blue
const diagnosticWarning = base_yellow; // Warning color - yellow
const linkColor = base_blue; // Link color - blue
// const visitedLinkColor = base_violet; // Visited link color - violet
/**
 * Enhanced editor theme styles for Solarized Light
 */
const solarizedLightTheme = /*@__PURE__*/EditorView.theme({
    // Base editor styles
    '&': {
        color: base00,
        backgroundColor: background,
        fontSize: generalContent.fontSize,
        fontFamily: generalContent.fontFamily,
    },
    // Content and cursor
    '.cm-content': {
        caretColor: cursor,
        lineHeight: generalContent.lineHeight,
    },
    '.cm-cursor, .cm-dropCursor': {
        borderLeftColor: cursor,
        borderLeftWidth: generalCursor.borderLeftWidth,
    },
    '.cm-fat-cursor': {
        backgroundColor: `${cursor}99`,
        color: background,
    },
    // Selection
    '&.cm-focused > .cm-scroller > .cm-selectionLayer .cm-selectionBackground, .cm-selectionBackground, .cm-content ::selection': {
        backgroundColor: selection,
    },
    // Make sure selection appears above active line
    '.cm-selectionLayer': {
        zIndex: 100,
    },
    // Search functionality
    '.cm-searchMatch': {
        backgroundColor: '#93a1a180',
        outline: `1px solid ${base_blue}`,
        color: base01,
        borderRadius: generalSearchField.borderRadius,
        '& span': {
            color: base01,
        },
    },
    '.cm-searchMatch.cm-searchMatch-selected': {
        backgroundColor: base_blue,
        color: base08,
        padding: generalSearchField.padding,
        '& span': {
            color: base08,
        },
    },
    '.cm-search.cm-panel.cm-textfield': {
        color: base00,
        borderRadius: generalSearchField.borderRadius,
        padding: generalSearchField.padding,
    },
    // Panels
    '.cm-panels': {
        backgroundColor: darkBackground,
        color: base00,
        borderRadius: '4px',
    },
    '.cm-panels.cm-panels-top': {
        borderBottom: `1px solid ${base04}`,
    },
    '.cm-panels.cm-panels-bottom': {
        borderTop: `1px solid ${base04}`,
    },
    '.cm-panel button': {
        backgroundColor: tooltipBackground,
        color: base00,
        border: generalPanel.border,
        borderRadius: generalPanel.borderRadius,
        padding: generalPanel.padding,
    },
    '.cm-panel button:hover': {
        backgroundColor: highlightBackground,
    },
    // Line highlighting
    '.cm-activeLine': {
        backgroundColor: highlightBackground,
        borderRadius: generalLine.borderRadius,
        zIndex: 1,
    },
    // Gutters
    '.cm-gutters': {
        backgroundColor: darkBackground,
        color: base01,
        border: generalGutter.border,
        borderRight: `1px solid ${base04}`,
        paddingRight: generalGutter.paddingRight,
    },
    '.cm-activeLineGutter': {
        backgroundColor: highlightBackground,
        color: base00,
        fontWeight: generalGutter.fontWeight,
    },
    '.cm-lineNumbers': {
        fontSize: generalGutter.fontSize,
    },
    '.cm-foldGutter': {
        fontSize: generalGutter.fontSize,
    },
    '.cm-foldGutter .cm-gutterElement': {
        color: base01,
        cursor: 'pointer',
    },
    '.cm-foldGutter .cm-gutterElement:hover': {
        color: base00,
    },
    // Tooltips and autocomplete
    '.cm-tooltip': {
        backgroundColor: tooltipBackground,
        border: `1px solid ${base01}`,
        borderRadius: generalTooltip.borderRadius,
        padding: generalTooltip.padding,
        boxShadow: '0 2px 8px rgba(0, 0, 0, 0.15)',
    },
    '.cm-tooltip-autocomplete': {
        '& > ul': {
            backgroundColor: tooltipBackground,
            border: 'none',
        },
        '& > ul > li': {
            padding: generalTooltip.padding,
            lineHeight: generalTooltip.lineHeight,
        },
        '& > ul > li[aria-selected]': {
            backgroundColor: selection,
            color: base01,
            borderRadius: generalTooltip.borderRadiusSelected,
        },
        '& > ul > li > span.cm-completionIcon': {
            color: base01,
            paddingRight: generalTooltip.paddingRight,
        },
        '& > ul > li > span.cm-completionDetail': {
            color: base01,
            fontStyle: 'italic',
        },
    },
    '.cm-tooltip .cm-tooltip-arrow:before': {
        borderTopColor: 'transparent',
        borderBottomColor: 'transparent',
    },
    '.cm-tooltip .cm-tooltip-arrow:after': {
        borderTopColor: tooltipBackground,
        borderBottomColor: tooltipBackground,
    },
    // Diagnostics styling
    '.cm-diagnostic': {
        '&-error': {
            borderLeft: `3px solid ${base_red}`,
        },
        '&-warning': {
            borderLeft: `3px solid ${diagnosticWarning}`,
        },
        '&-info': {
            borderLeft: `3px solid ${linkColor}`,
        },
    },
    '.cm-lintPoint-error': {
        borderBottom: `2px wavy ${base_red}`,
    },
    '.cm-lintPoint-warning': {
        borderBottom: `2px wavy ${diagnosticWarning}`,
    },
    // Matching brackets
    '.cm-matchingBracket': {
        backgroundColor: activeBracketBg,
        outline: `1px solid ${activeBracketBorder}`,
        borderRadius: generalMatching.borderRadius,
    },
    '.cm-nonmatchingBracket': {
        backgroundColor: `${base_red}40`,
        outline: `1px solid ${invalid}`,
        borderRadius: generalMatching.borderRadius,
    },
    // Selection matches
    '.cm-selectionMatch': {
        backgroundColor: selectionMatch,
        outline: `1px solid ${base05}50`,
        borderRadius: generalMatching.borderRadius,
    },
    // Fold placeholder
    '.cm-foldPlaceholder': {
        backgroundColor: tooltipBackground,
        color: base03,
        border: `1px dotted ${base05}70`,
        borderRadius: generalPlaceholder.borderRadius,
        padding: generalPlaceholder.padding,
        margin: generalPlaceholder.margin,
    },
    // Focus outline
    '&.cm-focused': {
        outline: 'none',
        boxShadow: `0 0 0 2px ${background}, 0 0 0 3px ${base_blue}40`,
    },
    // Scrollbars
    '& .cm-scroller::-webkit-scrollbar': {
        width: generalScroller.width,
        height: generalScroller.height,
    },
    '& .cm-scroller::-webkit-scrollbar-track': {
        background: darkBackground,
    },
    '& .cm-scroller::-webkit-scrollbar-thumb': {
        backgroundColor: base04,
        borderRadius: generalScroller.borderRadius,
        border: `3px solid ${darkBackground}`,
    },
    '& .cm-scroller::-webkit-scrollbar-thumb:hover': {
        backgroundColor: base05,
    },
    // Ghost text
    '.cm-ghostText': {
        opacity: '0.5',
        color: base01,
    },
}, { dark: false });
/**
 * Enhanced syntax highlighting for the Solarized Light theme
 */
const solarizedLightHighlightStyle = /*@__PURE__*/HighlightStyle.define([
    // Keywords and control flow
    { tag: tags.keyword, color: base_green, fontWeight: 'bold' },
    { tag: tags.controlKeyword, color: base_green, fontWeight: 'bold' },
    { tag: tags.moduleKeyword, color: base_green, fontWeight: 'bold' },
    // Names and variables
    { tag: [tags.name, tags.deleted, tags.character, tags.macroName], color: base_cyan },
    { tag: [tags.variableName], color: base00 },
    { tag: [tags.propertyName], color: base_cyan, fontStyle: 'normal' },
    // Classes and types
    { tag: [tags.typeName], color: base_orange },
    { tag: [tags.className], color: base_orange, fontStyle: 'italic' },
    { tag: [tags.namespace], color: base_magenta, fontStyle: 'italic' },
    // Operators and punctuation
    { tag: [tags.operator, tags.operatorKeyword], color: base_violet },
    { tag: [tags.bracket], color: base_magenta },
    { tag: [tags.brace], color: base_magenta },
    { tag: [tags.punctuation], color: base01 },
    // Functions and parameters
    { tag: [/*@__PURE__*/tags.function(tags.variableName)], color: base_blue },
    { tag: [tags.labelName], color: base_magenta },
    { tag: [/*@__PURE__*/tags.definition(/*@__PURE__*/tags.function(tags.variableName))], color: base_blue },
    { tag: [/*@__PURE__*/tags.definition(tags.variableName)], color: base_cyan },
    // Constants and literals
    { tag: tags.number, color: base_magenta },
    { tag: tags.changed, color: base_magenta },
    { tag: tags.annotation, color: invalid, fontStyle: 'italic' },
    { tag: tags.modifier, color: base_magenta, fontStyle: 'italic' },
    { tag: tags.self, color: base_magenta },
    {
        tag: [tags.color, /*@__PURE__*/tags.constant(tags.name), /*@__PURE__*/tags.standard(tags.name)],
        color: base_yellow,
    },
    { tag: [tags.atom, tags.bool, /*@__PURE__*/tags.special(tags.variableName)], color: base_magenta },
    // Strings and regex
    { tag: [tags.processingInstruction, tags.inserted], color: base_green },
    { tag: [/*@__PURE__*/tags.special(tags.string), tags.regexp], color: invalid },
    { tag: tags.string, color: base_yellow },
    // Punctuation and structure
    { tag: /*@__PURE__*/tags.definition(tags.typeName), color: base_orange, fontWeight: 'bold' },
    { tag: [/*@__PURE__*/tags.definition(tags.name), tags.separator], color: base_cyan },
    // Comments and documentation
    { tag: tags.meta, color: base_red },
    { tag: tags.comment, fontStyle: 'italic', color: base01 },
    { tag: tags.docComment, fontStyle: 'italic', color: base01 },
    // HTML/XML elements
    { tag: [tags.tagName], color: base_blue },
    { tag: [tags.attributeName], color: base00 },
    // Markdown and text formatting
    { tag: [tags.heading], fontWeight: 'bold', color: base_yellow },
    { tag: tags.heading1, color: base03 },
    { tag: tags.heading2, color: base02 },
    { tag: tags.heading3, color: base02 },
    { tag: tags.heading4, color: base02 },
    { tag: tags.heading5, color: base02 },
    { tag: tags.heading6, color: base02 },
    { tag: [tags.strong], fontWeight: 'bold', color: base02 },
    { tag: [tags.emphasis], fontStyle: 'italic', color: base_green },
    // Links and URLs
    {
        tag: [tags.link],
        color: base_cyan,
        fontWeight: '500',
        textDecoration: 'underline',
        textUnderlinePosition: 'under',
    },
    {
        tag: [tags.url],
        color: base_yellow,
        textDecoration: 'underline',
        textUnderlineOffset: '2px',
    },
    // Special states
    {
        tag: [tags.invalid],
        color: base01,
        textDecoration: 'underline wavy',
        borderBottom: `1px dotted ${base_red}`,
    },
    { tag: [tags.strikethrough], color: invalid, textDecoration: 'line-through' },
    // Enhanced syntax highlighting
    { tag: /*@__PURE__*/tags.constant(tags.name), color: base_yellow },
    { tag: tags.deleted, color: base_red },
    { tag: tags.squareBracket, color: base_red },
    { tag: tags.angleBracket, color: base01 },
    // Additional specific styles
    { tag: tags.monospace, color: base00 },
    { tag: [tags.contentSeparator], color: base_yellow },
    { tag: tags.quote, color: base_green },
]);
/**
 * Combined Solarized Light theme extension
 */
const solarizedLight = [
    solarizedLightTheme,
    /*@__PURE__*/syntaxHighlighting(solarizedLightHighlightStyle),
];

export { solarizedLight, solarizedLightHighlightStyle, solarizedLightTheme };
